@@ -696,6 +696,26 @@ typedef struct cuMemcpy3DPeerAsync_ptsz_params_st {
     CUstream hStream;
 } cuMemcpy3DPeerAsync_ptsz_params;
 
+typedef struct cuMemcpyBatchAsync_ptsz_params_st {
+    CUdeviceptr *dsts;
+    CUdeviceptr *srcs;
+    size_t *sizes;
+    size_t count;
+    CUmemcpyAttributes *attrs;
+    size_t *attrsIdxs;
+    size_t numAttrs;
+    size_t *failIdx;
+    CUstream hStream;
+} cuMemcpyBatchAsync_ptsz_params;
+
+typedef struct cuMemcpy3DBatchAsync_ptsz_params_st {
+    size_t numOps;
+    CUDA_MEMCPY3D_BATCH_OP *opList;
+    size_t *failIdx;
+    unsigned long long flags;
+    CUstream hStream;
+} cuMemcpy3DBatchAsync_ptsz_params;
+
 typedef struct cuMemsetD8_v2_ptds_params_st {
     CUdeviceptr dstDevice;
     unsigned char uc;
@@ -2380,6 +2400,77 @@ typedef struct cuGetExportTable_params_st {
     const CUuuid *pExportTableId;
 } cuGetExportTable_params;
 
+typedef struct cuGreenCtxCreate_params_st {
+    CUgreenCtx *phCtx;
+    CUdevResourceDesc desc;
+    CUdevice dev;
+    unsigned int flags;
+} cuGreenCtxCreate_params;
+
+typedef struct cuGreenCtxDestroy_params_st {
+    CUgreenCtx hCtx;
+} cuGreenCtxDestroy_params;
+
+typedef struct cuCtxFromGreenCtx_params_st {
+    CUcontext *pContext;
+    CUgreenCtx hCtx;
+} cuCtxFromGreenCtx_params;
+
+typedef struct cuDeviceGetDevResource_params_st {
+    CUdevice device;
+    CUdevResource *resource;
+    CUdevResourceType type;
+} cuDeviceGetDevResource_params;
+
+typedef struct cuCtxGetDevResource_params_st {
+    CUcontext hCtx;
+    CUdevResource *resource;
+    CUdevResourceType type;
+} cuCtxGetDevResource_params;
+
+typedef struct cuGreenCtxGetDevResource_params_st {
+    CUgreenCtx hCtx;
+    CUdevResource *resource;
+    CUdevResourceType type;
+} cuGreenCtxGetDevResource_params;
+
+typedef struct cuDevSmResourceSplitByCount_params_st {
+    CUdevResource *result;
+    unsigned int *nbGroups;
+    const CUdevResource *input;
+    CUdevResource *remaining;
+    unsigned int useFlags;
+    unsigned int minCount;
+} cuDevSmResourceSplitByCount_params;
+
+typedef struct cuDevResourceGenerateDesc_params_st {
+    CUdevResourceDesc *phDesc;
+    CUdevResource *resources;
+    unsigned int nbResources;
+} cuDevResourceGenerateDesc_params;
+
+typedef struct cuGreenCtxRecordEvent_params_st {
+    CUgreenCtx hCtx;
+    CUevent hEvent;
+} cuGreenCtxRecordEvent_params;
+
+typedef struct cuGreenCtxWaitEvent_params_st {
+    CUgreenCtx hCtx;
+    CUevent hEvent;
+} cuGreenCtxWaitEvent_params;
+
+typedef struct cuStreamGetGreenCtx_params_st {
+    CUstream hStream;
+    CUgreenCtx *phCtx;
+} cuStreamGetGreenCtx_params;
+
+typedef struct cuGreenCtxStreamCreate_params_st {
+    CUstream *phStream;
+    CUgreenCtx greenCtx;
+    unsigned int flags;
+    int priority;
+} cuGreenCtxStreamCreate_params;
+
 typedef struct cuMemHostRegister_params_st {
     void *p;
     size_t bytesize;
@@ -2909,6 +3000,26 @@ typedef struct cuMemcpy3DPeerAsync_params_st {
     CUstream hStream;
 } cuMemcpy3DPeerAsync_params;
 
+typedef struct cuMemcpyBatchAsync_params_st {
+    CUdeviceptr *dsts;
+    CUdeviceptr *srcs;
+    size_t *sizes;
+    size_t count;
+    CUmemcpyAttributes *attrs;
+    size_t *attrsIdxs;
+    size_t numAttrs;
+    size_t *failIdx;
+    CUstream hStream;
+} cuMemcpyBatchAsync_params;
+
+typedef struct cuMemcpy3DBatchAsync_params_st {
+    size_t numOps;
+    CUDA_MEMCPY3D_BATCH_OP *opList;
+    size_t *failIdx;
+    unsigned long long flags;
+    CUstream hStream;
+} cuMemcpy3DBatchAsync_params;
+
 typedef struct cuMemsetD8Async_params_st {
     CUdeviceptr dstDevice;
     unsigned char uc;
