@@ -15,7 +15,6 @@ typedef enum SANITIZER_CBID_RUNTIME_API_enum {
     SANITIZER_CBID_RUNTIME_API_cudaDriverGetVersion                                        = 1,
     SANITIZER_CBID_RUNTIME_API_cudaRuntimeGetVersion                                       = 2,
     SANITIZER_CBID_RUNTIME_API_cudaGetDeviceCount                                          = 3,
-    SANITIZER_CBID_RUNTIME_API_cudaGetDeviceProperties                                     = 4,
     SANITIZER_CBID_RUNTIME_API_cudaChooseDevice                                            = 5,
     SANITIZER_CBID_RUNTIME_API_cudaGetChannelDesc                                          = 6,
     SANITIZER_CBID_RUNTIME_API_cudaCreateChannelDesc                                       = 7,
@@ -63,14 +62,6 @@ typedef enum SANITIZER_CBID_RUNTIME_API_enum {
     SANITIZER_CBID_RUNTIME_API_cudaMemset2DAsync                                           = 52,
     SANITIZER_CBID_RUNTIME_API_cudaGetSymbolAddress                                        = 53,
     SANITIZER_CBID_RUNTIME_API_cudaGetSymbolSize                                           = 54,
-    SANITIZER_CBID_RUNTIME_API_cudaBindTexture                                             = 55,
-    SANITIZER_CBID_RUNTIME_API_cudaBindTexture2D                                           = 56,
-    SANITIZER_CBID_RUNTIME_API_cudaBindTextureToArray                                      = 57,
-    SANITIZER_CBID_RUNTIME_API_cudaUnbindTexture                                           = 58,
-    SANITIZER_CBID_RUNTIME_API_cudaGetTextureAlignmentOffset                               = 59,
-    SANITIZER_CBID_RUNTIME_API_cudaGetTextureReference                                     = 60,
-    SANITIZER_CBID_RUNTIME_API_cudaBindSurfaceToArray                                      = 61,
-    SANITIZER_CBID_RUNTIME_API_cudaGetSurfaceReference                                     = 62,
     SANITIZER_CBID_RUNTIME_API_cudaGLSetGLDevice                                           = 63,
     SANITIZER_CBID_RUNTIME_API_cudaGLRegisterBufferObject                                  = 64,
     SANITIZER_CBID_RUNTIME_API_cudaGLMapBufferObject                                       = 65,
@@ -131,12 +122,6 @@ typedef enum SANITIZER_CBID_RUNTIME_API_enum {
     SANITIZER_CBID_RUNTIME_API_cudaD3D9UnregisterVertexBuffer                              = 120,
     SANITIZER_CBID_RUNTIME_API_cudaD3D9MapVertexBuffer                                     = 121,
     SANITIZER_CBID_RUNTIME_API_cudaD3D9UnmapVertexBuffer                                   = 122,
-    SANITIZER_CBID_RUNTIME_API_cudaThreadExit                                              = 123,
-    SANITIZER_CBID_RUNTIME_API_cudaSetDoubleForDevice                                      = 124,
-    SANITIZER_CBID_RUNTIME_API_cudaSetDoubleForHost                                        = 125,
-    SANITIZER_CBID_RUNTIME_API_cudaThreadSynchronize                                       = 126,
-    SANITIZER_CBID_RUNTIME_API_cudaThreadGetLimit                                          = 127,
-    SANITIZER_CBID_RUNTIME_API_cudaThreadSetLimit                                          = 128,
     SANITIZER_CBID_RUNTIME_API_cudaStreamCreate                                            = 129,
     SANITIZER_CBID_RUNTIME_API_cudaStreamSynchronize                                       = 131,
     SANITIZER_CBID_RUNTIME_API_cudaStreamQuery                                             = 132,
@@ -146,18 +131,15 @@ typedef enum SANITIZER_CBID_RUNTIME_API_enum {
     SANITIZER_CBID_RUNTIME_API_cudaEventDestroy                                            = 136,
     SANITIZER_CBID_RUNTIME_API_cudaEventSynchronize                                        = 137,
     SANITIZER_CBID_RUNTIME_API_cudaEventQuery                                              = 138,
-    SANITIZER_CBID_RUNTIME_API_cudaEventElapsedTime                                        = 139,
     SANITIZER_CBID_RUNTIME_API_cudaMalloc3D                                                = 140,
     SANITIZER_CBID_RUNTIME_API_cudaMalloc3DArray                                           = 141,
     SANITIZER_CBID_RUNTIME_API_cudaMemset3D                                                = 142,
     SANITIZER_CBID_RUNTIME_API_cudaMemset3DAsync                                           = 143,
     SANITIZER_CBID_RUNTIME_API_cudaMemcpy3D                                                = 144,
     SANITIZER_CBID_RUNTIME_API_cudaMemcpy3DAsync                                           = 145,
-    SANITIZER_CBID_RUNTIME_API_cudaThreadSetCacheConfig                                    = 146,
     SANITIZER_CBID_RUNTIME_API_cudaStreamWaitEvent                                         = 147,
     SANITIZER_CBID_RUNTIME_API_cudaD3D11GetDirect3DDevice                                  = 148,
     SANITIZER_CBID_RUNTIME_API_cudaD3D10GetDirect3DDevice                                  = 149,
-    SANITIZER_CBID_RUNTIME_API_cudaThreadGetCacheConfig                                    = 150,
     SANITIZER_CBID_RUNTIME_API_cudaPointerGetAttributes                                    = 151,
     SANITIZER_CBID_RUNTIME_API_cudaHostRegister                                            = 152,
     SANITIZER_CBID_RUNTIME_API_cudaHostUnregister                                          = 153,
@@ -198,7 +180,6 @@ typedef enum SANITIZER_CBID_RUNTIME_API_enum {
     SANITIZER_CBID_RUNTIME_API_cudaMallocMipmappedArray                                    = 192,
     SANITIZER_CBID_RUNTIME_API_cudaGetMipmappedArrayLevel                                  = 193,
     SANITIZER_CBID_RUNTIME_API_cudaFreeMipmappedArray                                      = 194,
-    SANITIZER_CBID_RUNTIME_API_cudaBindTextureToMipmappedArray                             = 195,
     SANITIZER_CBID_RUNTIME_API_cudaGraphicsResourceGetMappedMipmappedArray                 = 196,
     SANITIZER_CBID_RUNTIME_API_cudaStreamAddCallback                                       = 197,
     SANITIZER_CBID_RUNTIME_API_cudaStreamCreateWithFlags                                   = 198,
@@ -253,9 +234,6 @@ typedef enum SANITIZER_CBID_RUNTIME_API_enum {
     SANITIZER_CBID_RUNTIME_API_cudaMemcpy3DPeer_ptds                                       = 249,
     SANITIZER_CBID_RUNTIME_API_cudaMemcpy3DPeerAsync_ptsz                                  = 250,
     SANITIZER_CBID_RUNTIME_API_cudaOccupancyMaxActiveBlocksPerMultiprocessorWithFlags      = 251,
-    SANITIZER_CBID_RUNTIME_API_cudaMemPrefetchAsync                                        = 252,
-    SANITIZER_CBID_RUNTIME_API_cudaMemPrefetchAsync_ptsz                                   = 253,
-    SANITIZER_CBID_RUNTIME_API_cudaMemAdvise                                               = 254,
     SANITIZER_CBID_RUNTIME_API_cudaDeviceGetP2PAttribute                                   = 255,
     SANITIZER_CBID_RUNTIME_API_cudaGraphicsEGLRegisterImage                                = 256,
     SANITIZER_CBID_RUNTIME_API_cudaEGLStreamConsumerConnect                                = 257,
@@ -273,17 +251,12 @@ typedef enum SANITIZER_CBID_RUNTIME_API_enum {
     SANITIZER_CBID_RUNTIME_API_cudaLaunchCooperativeKernel                                 = 269,
     SANITIZER_CBID_RUNTIME_API_cudaLaunchCooperativeKernel_ptsz                            = 270,
     SANITIZER_CBID_RUNTIME_API_cudaEventCreateFromEGLSync                                  = 271,
-    SANITIZER_CBID_RUNTIME_API_cudaLaunchCooperativeKernelMultiDevice                      = 272,
     SANITIZER_CBID_RUNTIME_API_cudaFuncSetAttribute                                        = 273,
     SANITIZER_CBID_RUNTIME_API_cudaImportExternalMemory                                    = 274,
     SANITIZER_CBID_RUNTIME_API_cudaExternalMemoryGetMappedBuffer                           = 275,
     SANITIZER_CBID_RUNTIME_API_cudaExternalMemoryGetMappedMipmappedArray                   = 276,
     SANITIZER_CBID_RUNTIME_API_cudaDestroyExternalMemory                                   = 277,
     SANITIZER_CBID_RUNTIME_API_cudaImportExternalSemaphore                                 = 278,
-    SANITIZER_CBID_RUNTIME_API_cudaSignalExternalSemaphoresAsync                           = 279,
-    SANITIZER_CBID_RUNTIME_API_cudaSignalExternalSemaphoresAsync_ptsz                      = 280,
-    SANITIZER_CBID_RUNTIME_API_cudaWaitExternalSemaphoresAsync                             = 281,
-    SANITIZER_CBID_RUNTIME_API_cudaWaitExternalSemaphoresAsync_ptsz                        = 282,
     SANITIZER_CBID_RUNTIME_API_cudaDestroyExternalSemaphore                                = 283,
     SANITIZER_CBID_RUNTIME_API_cudaLaunchHostFunc                                          = 284,
     SANITIZER_CBID_RUNTIME_API_cudaLaunchHostFunc_ptsz                                     = 285,
@@ -306,10 +279,6 @@ typedef enum SANITIZER_CBID_RUNTIME_API_enum {
     SANITIZER_CBID_RUNTIME_API_cudaGraphNodeFindInClone                                    = 302,
     SANITIZER_CBID_RUNTIME_API_cudaGraphNodeGetType                                        = 303,
     SANITIZER_CBID_RUNTIME_API_cudaGraphGetRootNodes                                       = 304,
-    SANITIZER_CBID_RUNTIME_API_cudaGraphNodeGetDependencies                                = 305,
-    SANITIZER_CBID_RUNTIME_API_cudaGraphNodeGetDependentNodes                              = 306,
-    SANITIZER_CBID_RUNTIME_API_cudaGraphAddDependencies                                    = 307,
-    SANITIZER_CBID_RUNTIME_API_cudaGraphRemoveDependencies                                 = 308,
     SANITIZER_CBID_RUNTIME_API_cudaGraphDestroyNode                                        = 309,
     SANITIZER_CBID_RUNTIME_API_cudaGraphLaunch                                             = 311,
     SANITIZER_CBID_RUNTIME_API_cudaGraphLaunch_ptsz                                        = 312,
@@ -323,9 +292,6 @@ typedef enum SANITIZER_CBID_RUNTIME_API_enum {
     SANITIZER_CBID_RUNTIME_API_cudaStreamEndCapture_ptsz                                   = 320,
     SANITIZER_CBID_RUNTIME_API_cudaGraphHostNodeSetParams                                  = 321,
     SANITIZER_CBID_RUNTIME_API_cudaGraphGetNodes                                           = 322,
-    SANITIZER_CBID_RUNTIME_API_cudaGraphGetEdges                                           = 323,
-    SANITIZER_CBID_RUNTIME_API_cudaStreamGetCaptureInfo                                    = 324,
-    SANITIZER_CBID_RUNTIME_API_cudaStreamGetCaptureInfo_ptsz                               = 325,
     SANITIZER_CBID_RUNTIME_API_cudaGraphExecKernelNodeSetParams                            = 326,
     SANITIZER_CBID_RUNTIME_API_cudaThreadExchangeStreamCaptureMode                         = 327,
     SANITIZER_CBID_RUNTIME_API_cudaDeviceGetNvSciSyncAttributes                            = 328,
@@ -391,10 +357,10 @@ typedef enum SANITIZER_CBID_RUNTIME_API_enum {
     SANITIZER_CBID_RUNTIME_API_cudaMemPoolImportPointer                                    = 390,
     SANITIZER_CBID_RUNTIME_API_cudaMallocFromPoolAsync                                     = 391,
     SANITIZER_CBID_RUNTIME_API_cudaMallocFromPoolAsync_ptsz                                = 392,
-    SANITIZER_CBID_RUNTIME_API_cudaSignalExternalSemaphoresAsync_v2                        = 393,
-    SANITIZER_CBID_RUNTIME_API_cudaSignalExternalSemaphoresAsync_v2_ptsz                   = 394,
-    SANITIZER_CBID_RUNTIME_API_cudaWaitExternalSemaphoresAsync_v2                          = 395,
-    SANITIZER_CBID_RUNTIME_API_cudaWaitExternalSemaphoresAsync_v2_ptsz                     = 396,
+    SANITIZER_CBID_RUNTIME_API_cudaSignalExternalSemaphoresAsync                           = 393,
+    SANITIZER_CBID_RUNTIME_API_cudaSignalExternalSemaphoresAsync_ptsz                      = 394,
+    SANITIZER_CBID_RUNTIME_API_cudaWaitExternalSemaphoresAsync                             = 395,
+    SANITIZER_CBID_RUNTIME_API_cudaWaitExternalSemaphoresAsync_ptsz                        = 396,
     SANITIZER_CBID_RUNTIME_API_cudaGraphAddExternalSemaphoresSignalNode                    = 397,
     SANITIZER_CBID_RUNTIME_API_cudaGraphExternalSemaphoresSignalNodeGetParams              = 398,
     SANITIZER_CBID_RUNTIME_API_cudaGraphExternalSemaphoresSignalNodeSetParams              = 399,
@@ -407,10 +373,6 @@ typedef enum SANITIZER_CBID_RUNTIME_API_enum {
     SANITIZER_CBID_RUNTIME_API_cudaGetDriverEntryPoint                                     = 406,
     SANITIZER_CBID_RUNTIME_API_cudaGetDriverEntryPoint_ptsz                                = 407,
     SANITIZER_CBID_RUNTIME_API_cudaGraphDebugDotPrint                                      = 408,
-    SANITIZER_CBID_RUNTIME_API_cudaStreamGetCaptureInfo_v2                                 = 409,
-    SANITIZER_CBID_RUNTIME_API_cudaStreamGetCaptureInfo_v2_ptsz                            = 410,
-    SANITIZER_CBID_RUNTIME_API_cudaStreamUpdateCaptureDependencies                         = 411,
-    SANITIZER_CBID_RUNTIME_API_cudaStreamUpdateCaptureDependencies_ptsz                    = 412,
     SANITIZER_CBID_RUNTIME_API_cudaUserObjectCreate                                        = 413,
     SANITIZER_CBID_RUNTIME_API_cudaUserObjectRetain                                        = 414,
     SANITIZER_CBID_RUNTIME_API_cudaUserObjectRelease                                       = 415,
@@ -436,31 +398,30 @@ typedef enum SANITIZER_CBID_RUNTIME_API_enum {
     SANITIZER_CBID_RUNTIME_API_cudaGraphInstantiateWithParams_ptsz                         = 437,
     SANITIZER_CBID_RUNTIME_API_cudaGraphExecGetFlags                                       = 438,
     SANITIZER_CBID_RUNTIME_API_cudaGetKernel                                               = 439,
-    SANITIZER_CBID_RUNTIME_API_cudaGetDeviceProperties_v2                                  = 440,
+    SANITIZER_CBID_RUNTIME_API_cudaGetDeviceProperties                                     = 440,
     SANITIZER_CBID_RUNTIME_API_cudaStreamGetId                                             = 441,
     SANITIZER_CBID_RUNTIME_API_cudaStreamGetId_ptsz                                        = 442,
     SANITIZER_CBID_RUNTIME_API_cudaGraphInstantiate                                        = 443,
     SANITIZER_CBID_RUNTIME_API_cudaInitDevice                                              = 444,
-    SANITIZER_CBID_RUNTIME_API_cudaGraphAddNode                                            = 445,
     SANITIZER_CBID_RUNTIME_API_cudaGraphNodeSetParams                                      = 446,
     SANITIZER_CBID_RUNTIME_API_cudaGraphExecNodeSetParams                                  = 447,
-    SANITIZER_CBID_RUNTIME_API_cudaMemAdvise_v2                                            = 448,
-    SANITIZER_CBID_RUNTIME_API_cudaMemPrefetchAsync_v2                                     = 449,
-    SANITIZER_CBID_RUNTIME_API_cudaMemPrefetchAsync_v2_ptsz                                = 450,
+    SANITIZER_CBID_RUNTIME_API_cudaMemAdvise                                               = 448,
+    SANITIZER_CBID_RUNTIME_API_cudaMemPrefetchAsync                                        = 449,
+    SANITIZER_CBID_RUNTIME_API_cudaMemPrefetchAsync_ptsz                                   = 450,
     SANITIZER_CBID_RUNTIME_API_cudaFuncGetName                                             = 451,
     SANITIZER_CBID_RUNTIME_API_cudaStreamBeginCaptureToGraph                               = 452,
     SANITIZER_CBID_RUNTIME_API_cudaStreamBeginCaptureToGraph_ptsz                          = 453,
     SANITIZER_CBID_RUNTIME_API_cudaGraphConditionalHandleCreate                            = 454,
-    SANITIZER_CBID_RUNTIME_API_cudaGraphGetEdges_v2                                        = 455,
-    SANITIZER_CBID_RUNTIME_API_cudaGraphNodeGetDependencies_v2                             = 456,
-    SANITIZER_CBID_RUNTIME_API_cudaGraphNodeGetDependentNodes_v2                           = 457,
-    SANITIZER_CBID_RUNTIME_API_cudaGraphAddDependencies_v2                                 = 458,
-    SANITIZER_CBID_RUNTIME_API_cudaGraphRemoveDependencies_v2                              = 459,
-    SANITIZER_CBID_RUNTIME_API_cudaGraphAddNode_v2                                         = 460,
-    SANITIZER_CBID_RUNTIME_API_cudaStreamGetCaptureInfo_v3                                 = 461,
-    SANITIZER_CBID_RUNTIME_API_cudaStreamGetCaptureInfo_v3_ptsz                            = 462,
-    SANITIZER_CBID_RUNTIME_API_cudaStreamUpdateCaptureDependencies_v2                      = 463,
-    SANITIZER_CBID_RUNTIME_API_cudaStreamUpdateCaptureDependencies_v2_ptsz                 = 464,
+    SANITIZER_CBID_RUNTIME_API_cudaGraphGetEdges                                           = 455,
+    SANITIZER_CBID_RUNTIME_API_cudaGraphNodeGetDependencies                                = 456,
+    SANITIZER_CBID_RUNTIME_API_cudaGraphNodeGetDependentNodes                              = 457,
+    SANITIZER_CBID_RUNTIME_API_cudaGraphAddDependencies                                    = 458,
+    SANITIZER_CBID_RUNTIME_API_cudaGraphRemoveDependencies                                 = 459,
+    SANITIZER_CBID_RUNTIME_API_cudaGraphAddNode                                            = 460,
+    SANITIZER_CBID_RUNTIME_API_cudaStreamGetCaptureInfo                                    = 461,
+    SANITIZER_CBID_RUNTIME_API_cudaStreamGetCaptureInfo_ptsz                               = 462,
+    SANITIZER_CBID_RUNTIME_API_cudaStreamUpdateCaptureDependencies                         = 463,
+    SANITIZER_CBID_RUNTIME_API_cudaStreamUpdateCaptureDependencies_ptsz                    = 464,
     SANITIZER_CBID_RUNTIME_API_cudaDeviceRegisterAsyncNotification                         = 465,
     SANITIZER_CBID_RUNTIME_API_cudaDeviceUnregisterAsyncNotification                       = 466,
     SANITIZER_CBID_RUNTIME_API_cudaFuncGetParamInfo                                        = 467,
@@ -478,12 +439,44 @@ typedef enum SANITIZER_CBID_RUNTIME_API_enum {
     SANITIZER_CBID_RUNTIME_API_cudaKernelSetAttributeForDevice                             = 479,
     SANITIZER_CBID_RUNTIME_API_cudaStreamGetDevice                                         = 480,
     SANITIZER_CBID_RUNTIME_API_cudaStreamGetDevice_ptsz                                    = 481,
-    SANITIZER_CBID_RUNTIME_API_cudaMemcpyBatchAsync                                        = 482,
-    SANITIZER_CBID_RUNTIME_API_cudaMemcpyBatchAsync_ptsz                                   = 483,
-    SANITIZER_CBID_RUNTIME_API_cudaMemcpy3DBatchAsync                                      = 484,
-    SANITIZER_CBID_RUNTIME_API_cudaMemcpy3DBatchAsync_ptsz                                 = 485,
-    SANITIZER_CBID_RUNTIME_API_cudaEventElapsedTime_v2                                     = 486,
-    SANITIZER_CBID_RUNTIME_API_SIZE                                                        = 487,
+    SANITIZER_CBID_RUNTIME_API_cudaEventElapsedTime                                        = 486,
+    SANITIZER_CBID_RUNTIME_API_cudaMemPrefetchBatchAsync                                   = 487,
+    SANITIZER_CBID_RUNTIME_API_cudaMemPrefetchBatchAsync_ptsz                              = 488,
+    SANITIZER_CBID_RUNTIME_API_cudaMemDiscardBatchAsync                                    = 489,
+    SANITIZER_CBID_RUNTIME_API_cudaMemDiscardBatchAsync_ptsz                               = 490,
+    SANITIZER_CBID_RUNTIME_API_cudaMemDiscardAndPrefetchBatchAsync                         = 491,
+    SANITIZER_CBID_RUNTIME_API_cudaMemDiscardAndPrefetchBatchAsync_ptsz                    = 492,
+    SANITIZER_CBID_RUNTIME_API_cudaGetExportTable                                          = 493,
+    SANITIZER_CBID_RUNTIME_API___cudaRegisterFatBinary                                     = 494,
+    SANITIZER_CBID_RUNTIME_API___cudaRegisterFatBinaryEnd                                  = 495,
+    SANITIZER_CBID_RUNTIME_API___cudaUnregisterFatBinary                                   = 496,
+    SANITIZER_CBID_RUNTIME_API___cudaRegisterVar                                           = 497,
+    SANITIZER_CBID_RUNTIME_API___cudaRegisterHostVar                                       = 498,
+    SANITIZER_CBID_RUNTIME_API___cudaRegisterFunction                                      = 499,
+    SANITIZER_CBID_RUNTIME_API___cudaRegisterManagedVar                                    = 500,
+    SANITIZER_CBID_RUNTIME_API___cudaInitModule                                            = 501,
+    SANITIZER_CBID_RUNTIME_API___cudaPushCallConfiguration                                 = 502,
+    SANITIZER_CBID_RUNTIME_API___cudaPopCallConfiguration                                  = 503,
+    SANITIZER_CBID_RUNTIME_API___cudaGetKernel                                             = 504,
+    SANITIZER_CBID_RUNTIME_API___cudaLaunchKernel                                          = 505,
+    SANITIZER_CBID_RUNTIME_API___cudaLaunchKernel_ptsz                                     = 506,
+    SANITIZER_CBID_RUNTIME_API___cudaRegisterUnifiedTable                                  = 507,
+    SANITIZER_CBID_RUNTIME_API___cudaGetProcAddress                                        = 508,
+    SANITIZER_CBID_RUNTIME_API_cudaMemcpyBatchAsync                                        = 509,
+    SANITIZER_CBID_RUNTIME_API_cudaMemcpyBatchAsync_ptsz                                   = 510,
+    SANITIZER_CBID_RUNTIME_API_cudaMemcpy3DBatchAsync                                      = 511,
+    SANITIZER_CBID_RUNTIME_API_cudaMemcpy3DBatchAsync_ptsz                                 = 512,
+    SANITIZER_CBID_RUNTIME_API_cudaLogsRegisterCallback                                    = 513,
+    SANITIZER_CBID_RUNTIME_API_cudaLogsUnregisterCallback                                  = 514,
+    SANITIZER_CBID_RUNTIME_API_cudaLogsCurrent                                             = 515,
+    SANITIZER_CBID_RUNTIME_API_cudaLogsDumpToFile                                          = 516,
+    SANITIZER_CBID_RUNTIME_API_cudaLogsDumpToMemory                                        = 517,
+    SANITIZER_CBID_RUNTIME_API_cudaMemGetDefaultMemPool                                    = 518,
+    SANITIZER_CBID_RUNTIME_API_cudaMemGetMemPool                                           = 519,
+    SANITIZER_CBID_RUNTIME_API_cudaMemSetMemPool                                           = 520,
+    SANITIZER_CBID_RUNTIME_API_cudaDeviceGetHostAtomicCapabilities                         = 521,
+    SANITIZER_CBID_RUNTIME_API_cudaDeviceGetP2PAtomicCapabilities                          = 522,
+    SANITIZER_CBID_RUNTIME_API_SIZE                                                        = 523,
     SANITIZER_CBID_RUNTIME_API_FORCE_INT                                                   = 0x7fffffff
 } SANITIZER_CBID_RUNTIME_API;
 
