@@ -1,4 +1,4 @@
-# SPDX-FileCopyrightText: Copyright (c) 2023-2024 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
+# SPDX-FileCopyrightText: Copyright (c) 2023-2025 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
 # SPDX-License-Identifier: LicenseRef-NvidiaProprietary
 #
 # NVIDIA CORPORATION, its affiliates and licensors retain all intellectual
@@ -10,6 +10,7 @@
 
 import math
 import platform
+import re
 
 import numpy as np
 import plotly.express as px
@@ -217,6 +218,15 @@ def _get_heatmap_height(name_count, plot_count=1):
     return (name_count * 27 + 110) * plot_count
 
 
+def _split_numeric(input_string):
+    # This function is meant to be used as the sorting key function to sort the
+    # input string in a way that respects the numerical order of any numbers it
+    # contains.
+    # Extract numeric and non-numeric parts.
+    parts = re.findall(r"\d+|\D+", input_string)
+    return [int(part) if part.isdigit() else part for part in parts]
+
+
 def display_heatmaps(
     df, types, xaxis_title, yaxis_title, zaxis_title, zmax=100, **layout_args
 ):
@@ -244,9 +254,16 @@ def display_heatmaps(
     fig.update_layout(height=height, **layout_args)
     fig.update_xaxes(title=xaxis_title)
     fig.update_yaxes(
-        title=yaxis_title, categoryorder="category descending", nticks=unique_name_count
+        title=yaxis_title,
+        categoryorder="array",
+        categoryarray=sorted(df["Name"], key=_split_numeric, reverse=True),
+        nticks=unique_name_count,
+    )
+    fig.update_traces(
+        {"colorbar": {"title_text": zaxis_title}},
+        showscale=True,
+        row=0,
     )
-    fig.update_traces({"colorbar": {"title_text": zaxis_title}}, showscale=True, row=0)
     fig.update_traces(
         hovertemplate=f"{xaxis_title}: %{{x}}<br>{yaxis_title}: %{{y}}<br>{zaxis_title}: %{{z}}<extra></extra>"
     )
@@ -254,20 +271,39 @@ def display_heatmaps(
 
 
 def display_heatmap(
-    df, value_col, xaxis_title, yaxis_title, zaxis_title, zmax=100, **layout_args
+    df,
+    value_col,
+    xaxis_title,
+    yaxis_title,
+    zaxis_title,
+    zmax=100,
+    zaxis_tickformat=None,
+    **layout_args,
 ):
-    fig = px.imshow(
-        df.pivot(index="Name", columns="Duration")[value_col], range_color=(0, zmax)
+    fig = make_subplots(1, 1, subplot_titles=[value_col], vertical_spacing=0.1)
+    fig.add_trace(
+        go.Heatmap(
+            x=df["Duration"],
+            y=df["Name"],
+            z=df[value_col],
+            zmax=zmax,
+            zauto=False,
+            colorbar={"title": zaxis_title, "tickformat": zaxis_tickformat},
+        )
     )
 
     unique_name_count = df["Name"].nunique()
     fig.update_layout(
         height=_get_heatmap_height(unique_name_count),
-        coloraxis_colorbar_title=zaxis_title,
         **layout_args,
     )
     fig.update_xaxes(title=xaxis_title)
-    fig.update_yaxes(title=yaxis_title, nticks=unique_name_count)
+    fig.update_yaxes(
+        title=yaxis_title,
+        categoryorder="array",
+        categoryarray=sorted(df["Name"], key=_split_numeric, reverse=True),
+        nticks=unique_name_count,
+    )
     fig.update_traces(
         hovertemplate=f"{xaxis_title}: %{{x}}<br>{yaxis_title}: %{{y}}<br>{zaxis_title}: %{{z}}<extra></extra>"
     )
@@ -379,6 +415,7 @@ def display_histogram(
             title_text=f"{title}, bins={bin_size}",
             xaxis_title_text=xaxis_title,
             yaxis_title_text=yaxis_title,
+            **layout_args,
         )
 
         fig.update_traces(
@@ -402,11 +439,14 @@ def get_unique_index_values(grouped, partial_key=None):
         key_tuple = tuple(partial_key)
         group_keys = [key for key in group_keys if key[:n] == key_tuple]
 
-    if len(grouped.grouper.names) == 1:
-        unique_values = [sorted(set(group_keys))]
-    else:
+    if not group_keys:
+        return []
+
+    if isinstance(group_keys[0], tuple):
         unique_values = list(zip(*group_keys))
         unique_values = [sorted(set(level)) for level in unique_values]
+    else:
+        unique_values = [sorted(set(group_keys))]
 
     return unique_values
 
@@ -465,14 +505,15 @@ def _initialize_dropdowns_per_column(index_grouped, group_by_columns):
     # We want to update the dropdowns based on the value of the first dropdown.
     # Since ipywidgets doesn't trigger the observer if the value is the same,
     # we temporarily set the value to None and then restore the original value.
-    original_value = dropdowns["Rank"].value
-    dropdowns["Rank"].value = None
-    dropdowns["Rank"].value = original_value
+    if "Rank" in dropdowns:
+        original_value = dropdowns["Rank"].value
+        dropdowns["Rank"].value = None
+        dropdowns["Rank"].value = original_value
 
     return dropdowns, description_width
 
 
-def display_stats_per_column(df, group_by_columns):
+def display_stats_per_column(df, group_by_columns, post_process_fn=None):
     if df.empty:
         display(df)
         return
@@ -486,10 +527,19 @@ def display_stats_per_column(df, group_by_columns):
             if group_key not in index_grouped.groups:
                 return
         else:
-            group_key = selected_values[group_by_columns[0]]
+            group_key = (selected_values[group_by_columns[0]],)
 
-        display_df = index_grouped.get_group(group_key)
-        display(display_df.reset_index(drop=True))
+        display_df = index_grouped.get_group(group_key).reset_index(drop=True)
+
+        if post_process_fn is not None:
+            display_objects = post_process_fn(display_df)
+            if isinstance(display_objects, list):
+                for obj in display_objects:
+                    display(obj)
+            else:
+                display(display_objects)
+        else:
+            display(display_df)
 
     dropdowns, _ = _initialize_dropdowns_per_column(index_grouped, group_by_columns)
     interact(display_table, **dropdowns)
