@@ -32,6 +32,7 @@ requested_metrics = [
     MetricRequest("gpu__compute_memory_throughput.avg.pct_of_peak_sustained_elapsed", "mem_sol_pct", Importance.OPTIONAL, None, False),
     MetricRequest("breakdown:gpu__compute_memory_throughput.avg.pct_of_peak_sustained_elapsed", "breakdown_memory", Importance.OPTIONAL, None, False),
     MetricRequest("launch__waves_per_multiprocessor", "num_waves", Importance.OPTIONAL, None, False),
+    MetricRequest("launch__uses_nvlink_centric_scheduling", "nvlink_scheduling", Importance.OPTIONAL, None, False),
 ]
 
 
@@ -165,6 +166,14 @@ def apply(handle):
     for focus_metric in focus_metrics:
         fe.focus_metric(msg_id, focus_metric[0], focus_metric[1], focus_metric[2], focus_metric[3])
 
+    if sm_sol_pct < no_bound_threshold:
+        nvlink_scheduling_metric = metrics["nvlink_scheduling"]
+        if nvlink_scheduling_metric and nvlink_scheduling_metric.value():
+            message = "This workload uses NVLink-centric scheduling. Some SM resources may not be available to this workload, which can result in lower-than-expected measured utilization."
+            msg_id = fe.message(NvRules.MsgType.WARNING, message, "NVLink-Centric Scheduling")
+            fe.focus_metric(msg_id, nvlink_scheduling_metric.name(), nvlink_scheduling_metric.value(), NvRules.IFrontend.Severity_SEVERITY_HIGH, "Indicates NVLink-centric scheduling.")
+            fe.focus_metric(msg_id, sm_sol_pct_metric.name(), sm_sol_pct_metric.value(), NvRules.IFrontend.Severity_SEVERITY_DEFAULT, "Achievable SM peak values may be lower than usual.")
+
     # Send weights to child rules (with values in [0,1])
     fe.send_dict_to_children(
         {
