@@ -1,6 +1,6 @@
-#!/bin/bash -x
+#!/usr/bin/env bash
 
-# SPDX-FileCopyrightText: Copyright (c) 2023 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
+# SPDX-FileCopyrightText: Copyright (c) 2023-2024 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
 # SPDX-License-Identifier: Apache-2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -15,13 +15,14 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-SCRIPT=`readlink -f $0`
-HERE=`dirname $SCRIPT`
+set -euxo pipefail
 
-if [ -z "$DEVTOOL_CMD" ]; then
-    echo "Set DEVTOOL_DIR and DEVTOOL_CMD to map a devtool into the container and have it auto-start!" 1>&2
+SCRIPT=$(readlink -f $0)
+HERE=$(dirname $SCRIPT)
+
+if [ -z "$DEVTOOL_DIR" ] || [ -z "$DEVTOOL_CMD" ]; then
+    echo "Error: Both DEVTOOL_DIR and DEVTOOL_CMD must be set to map a devtool into the container and have it auto-start!" >&2
 else
-    #NOTE: DEVTOOL_DIR is mapped to /mnt/host/devtool/
-    DEVTOOL_CMD=`echo $DEVTOOL_CMD | sed "s/^\([\"']\)\(.*\)\1\$/\2/g"`
-    /mnt/host/devtool/$DEVTOOL_CMD
-fi
\ No newline at end of file
+    DEVTOOL_CMD=$(echo "$DEVTOOL_CMD" | sed "s/^\([\"']\)\(.*\)\1$/\2/g")
+    "$DEVTOOL_DIR"/$DEVTOOL_CMD
+fi
