@@ -21,6 +21,16 @@ struct syscall_trace_data {
     __u32 tgid;
     __u32 pid;
     __u16 seq_nr;
+    __u16 ustack_byte_size;
+
+    /*
+     * Buffer for storing user space backtrace which leads to the system call.
+     * Implemented as a flexible array field (see [1] for details) to make
+     * the buffer size configurable, as it directly affects memory consumption.
+     *
+     * [1] https://www.gnu.org/software/c-intro-and-ref/manual/html_node/Flexible-Array-Fields.html
+     */
+    __u64 ustack[];
 };
 
 #endif /* SYSCALL_TRACE_H */
